@@ -100,7 +100,9 @@ typedef short int16_t;
 typedef char int8_t;
 #endif
 
-typedef unsigned char bool;
+#ifndef bool
+#define bool u_int8_t
+#endif
 
 #include "fcUtils.h"
 #include "scsiUtils.h"
@@ -394,6 +396,8 @@ typedef struct packetStats {
   TrafficCounter badChecksum, tooLong;
 } PacketStats;
 
+/* *********************** */
+
 typedef struct fcPacketStats {
   TrafficCounter upTo36, upTo48, upTo52, upTo68, upTo104;
   TrafficCounter upTo548, upTo1060, upTo2136, above2136;
@@ -411,7 +415,7 @@ typedef struct ttlStats {
 /* *********************** */
 
 typedef struct simpleProtoTrafficInfo {
-  TrafficCounter local, local2remote, remote, remote2local;
+  TrafficCounter local, local2remote, remote, remote2local; /* Bytes */
   TrafficCounter totalFlows;
 } SimpleProtoTrafficInfo;
 
@@ -440,7 +444,9 @@ typedef struct securityHostProbes {
   UsageCounter rejectedTCPConnSent, rejectedTCPConnRcvd;
   UsageCounter establishedTCPConnSent, establishedTCPConnRcvd;
   UsageCounter terminatedTCPConnServer, terminatedTCPConnClient;
+
   /* ********* */
+
   UsageCounter udpToClosedPortSent, udpToClosedPortRcvd;
 
   UsageCounter udpToDiagnosticPortSent, udpToDiagnosticPortRcvd,
@@ -478,9 +484,13 @@ typedef struct securityDeviceProbes {
   TrafficCounter icmpAdminProhibited;
 } SecurityDeviceProbes;
 
+/* *********************** */
+
 typedef struct sapType {
   u_char dsap, ssap;
 } SapType;
+\
+/* *********************** */
 
 typedef struct unknownProto {
   u_char protoType; /* 0=notUsed, 1=Ethernet, 2=SAP, 3=IP */
@@ -491,6 +501,8 @@ typedef struct unknownProto {
   } proto;
 } UnknownProto;
 
+/* *********************** */
+
 typedef struct nonIPTraffic {
   /* NetBIOS */
   char             nbNodeType, *nbHostName, *nbAccountName, *nbDomainName, *nbDescr;
@@ -507,22 +519,24 @@ typedef struct nonIPTraffic {
   /* Non IP */
   TrafficCounter   stpSent, stpRcvd; /* Spanning Tree */
   TrafficCounter   ipxSent, ipxRcvd;
-  TrafficCounter   osiSent, osiRcvd;
   TrafficCounter   dlcSent, dlcRcvd;
   TrafficCounter   arp_rarpSent, arp_rarpRcvd;
   TrafficCounter   arpReqPktsSent, arpReplyPktsSent, arpReplyPktsRcvd;
-  TrafficCounter   decnetSent, decnetRcvd;
   TrafficCounter   appletalkSent, appletalkRcvd;
   TrafficCounter   netbiosSent, netbiosRcvd;
   TrafficCounter   otherSent, otherRcvd; /* Other traffic we cannot classify */
   UnknownProto     *unknownProtoSent, *unknownProtoRcvd; /* List of MAX_NUM_UNKNOWN_PROTOS elements */
 } NonIPTraffic;
 
+/* *********************** */
+
 typedef struct trafficDistribution {
   TrafficCounter lastCounterBytesSent, last24HoursBytesSent[25], lastDayBytesSent;
   TrafficCounter lastCounterBytesRcvd, last24HoursBytesRcvd[25], lastDayBytesRcvd;
 } TrafficDistribution;
 
+/* *********************** */
+
 typedef struct portUsage {
   u_short        port, clientUses, serverUses;
   HostSerial     clientUsesLastPeer, serverUsesLastPeer;
@@ -530,24 +544,32 @@ typedef struct portUsage {
   struct portUsage *next;
 } PortUsage;
 
+/* *********************** */
+
 typedef struct virtualHostList {
   char *virtualHostName;
   TrafficCounter bytesSent, bytesRcvd; /* ... by the virtual host */
   struct virtualHostList *next;
 } VirtualHostList;
 
+/* *********************** */
+
 typedef struct userList {
   char *userName;
   fd_set userFlags;
   struct userList *next;
 } UserList;
 
+/* *********************** */
+
 typedef struct fileList {
   char *fileName;
   fd_set fileFlags;
   struct fileList *next;
 } FileList;
 
+/* *********************** */
+
 typedef struct storedAddress {
   char   symAddress[MAX_LEN_SYM_HOST_NAME];
   time_t recordCreationTime;
@@ -555,11 +577,15 @@ typedef struct storedAddress {
   char   pad; /* Quiet valgrind */
 } StoredAddress;
 
+/* *********************** */
+
 typedef struct macInfo {
   u_char isSpecial;
   char   vendorName[MAX_LEN_VENDOR_NAME];
 } MACInfo;
 
+/* *********************** */
+
 typedef struct serviceStats {
   TrafficCounter numLocalReqSent, numRemReqSent;
   TrafficCounter numPositiveReplSent, numNegativeReplSent;
@@ -571,6 +597,7 @@ typedef struct serviceStats {
   time_t fastestMicrosecRemReqServed, slowestMicrosecRemReqServed;
 } ServiceStats;
 
+/* *********************** */
 
 typedef struct dhcpStats {
   struct in_addr dhcpServerIpAddress;  /* DHCP server that assigned the address */
@@ -587,12 +614,16 @@ typedef struct dhcpStats {
 #define ICMP6_MAXTYPE 142
 #endif
 
+/* *********************** */
+
 typedef struct icmpHostInfo {
   TrafficCounter icmpMsgSent[ICMP6_MAXTYPE+1];
   TrafficCounter icmpMsgRcvd[ICMP6_MAXTYPE+1];
   time_t        lastUpdated;
 } IcmpHostInfo;
 
+/* *********************** */
+
 typedef struct protocolInfo {
   /* HTTP */
   VirtualHostList *httpVirtualHosts;
@@ -604,16 +635,24 @@ typedef struct protocolInfo {
   DHCPStats        *dhcpStats;
 } ProtocolInfo;
 
+/* *********************** */
+
 typedef struct shortProtoTrafficInfo {
-  TrafficCounter sent, rcvd;
+  TrafficCounter sent, rcvd; /* Bytes */
 } ShortProtoTrafficInfo;
 
+/* *********************** */
+
 typedef struct protoTrafficInfo {
   TrafficCounter sentLoc, sentRem;
   TrafficCounter rcvdLoc, rcvdFromRem;
+  TrafficCounter pktSent, pktRcvd, efficiencySent, efficiencyRcvd;
+  TrafficCounter lastEfficiencyPktSent, lastEfficiencyPktRcvd; /* Used by the RRD plugin */
   TrafficCounter totalFlows;
 } ProtoTrafficInfo;
 
+/* *********************** */
+
 #define MAX_NUM_NON_IP_PROTO_TRAFFIC_INFO   8
 
 typedef struct nonIpProtoTrafficInfo {
@@ -623,11 +662,12 @@ typedef struct nonIpProtoTrafficInfo {
   struct nonIpProtoTrafficInfo *next;
 } NonIpProtoTrafficInfo;
 
+/* *********************** */
+
 /* ************************************* */
 /*         SCSI-specific structures      */
 /* ************************************* */
 
-
 typedef struct scsiLunTrafficInfo {
     struct timeval firstSeen;         /* time when the session has been initiated   */
     struct timeval lastSeen;          /* time when the session has been closed      */
@@ -769,43 +809,57 @@ typedef struct fcScsiCounters {
 
 /* **************************** */
 
+typedef struct networkDelay {
+  struct timeval last_update;
+  u_long min_nw_delay, max_nw_delay;
+  u_int num_samples;
+  double total_delay;
+  u_int16_t peer_port;
+  HostSerial last_peer;
+} NetworkDelay;
+
+/* **************************** */
+
 #define hostIp4Address hostIpAddress.Ip4Address
 #define hostIp6Address hostIpAddress.Ip6Address
 
-
 /* Host Traffic */
 typedef struct hostTraffic {
   u_int8_t         to_be_deleted; /* 1 = the host will be deleted in the next purge loop */
   u_short          magic;
   u_short          l2Family;    /* 0 = Ethernet, 1 = Fibre Channel (FC) */
   u_int            hostTrafficBucket; /* Index in the **hash_hostTraffic list */
-  u_int            originalHostTrafficBucket; /* REMOVE */
   u_short          refCount;         /* Reference counter */
   HostSerial       hostSerial;
   HostAddr         hostIpAddress;
-  u_int16_t        vlanId;           /* VLAN Id (-1 if not set) */
+  u_int16_t        vlanId;          /* VLAN Id (-1 if not set) */
   u_int16_t        ifId;            /* Interface Id [e.g. for NetFlow] (-1 if not set) */
-  u_int16_t        hostAS;           /* AS to which the host belongs to */
+  u_int16_t        hostAS;          /* AS to which the host belongs to */
   time_t           firstSeen, lastSeen; /* time when this host has sent/rcvd some data  */
   u_char           ethAddress[LEN_ETHERNET_ADDRESS];
   u_char           lastEthAddress[LEN_ETHERNET_ADDRESS]; /* used for remote addresses */
   char             ethAddressString[LEN_ETHERNET_ADDRESS_DISPLAY];
   char             hostNumIpAddress[20] /* xxx.xxx.xxx.xxx */, *dnsDomainValue, *dnsTLDValue;
-  u_char           network_mask; /* IPv6 notation e.g. /24 */
-  char             *hwModel, *description, *community;
-  char             *ip2ccValue, *fingerprint;
+  u_int8_t         network_mask;    /* IPv6 notation e.g. /24 */
+  int8_t           known_subnet_id; /* UNKNOWN_SUBNET_ID if the host does not belong to a known subnet */
+  char             *hwModel, *description, *community, *ip2ccValue, *fingerprint;
   char             hostResolvedName[MAX_LEN_SYM_HOST_NAME];
   short            hostResolvedNameType;
   u_short          minTTL, maxTTL; /* IP TTL (Time-To-Live) */
   struct timeval   minLatency, maxLatency;
 
+  TrafficCounter   greSent, greRcvd, greEfficiencySent, greEfficiencyRcvd,
+    grePktSent, grePktRcvd, lastGrePktSent, lastGrePktRcvd;
+  TrafficCounter   ipsecSent, ipsecRcvd, ipsecEfficiencySent, ipsecEfficiencyRcvd,
+    ipsecPktSent, ipsecPktRcvd, lastIpsecPktSent, lastIpsecPktRcvd;
+
   NonIPTraffic     *nonIPTraffic;
   NonIpProtoTrafficInfo *nonIpProtoTrafficInfos; /* Info about further non IP protos */
 
   fd_set           flags;
   TrafficCounter   pktSent, pktRcvd, pktSentSession, pktRcvdSession,
-    pktDuplicatedAckSent, pktDuplicatedAckRcvd;
-  TrafficCounter   lastPktSent, lastPktRcvd;
+    pktDuplicatedAckSent, pktDuplicatedAckRcvd, efficiencySent, efficiencyRcvd;
+  TrafficCounter   lastThptPktSent, lastThptPktRcvd, lastEfficiencyPktSent, lastEfficiencyPktRcvd;
   TrafficCounter   pktBroadcastSent, bytesBroadcastSent;
   TrafficCounter   pktMulticastSent, bytesMulticastSent,
     pktMulticastRcvd, bytesMulticastRcvd;
@@ -829,10 +883,13 @@ typedef struct hostTraffic {
   /* IP */
   PortUsage        *portsUsage; /* 0...MAX_ASSIGNED_IP_PORTS */
 
+  /* NetworkDelay Stats */
+  NetworkDelay *clientDelay /* 0..MAX_NUM_NET_DELAY_STATS-1 */, *serverDelay /* 0 ..MAX_NUM_NET_DELAY_STATS-1 */;
+
   /* Don't change the recentl... to unsigned ! */
   int              recentlyUsedClientPorts[MAX_NUM_RECENT_PORTS], recentlyUsedServerPorts[MAX_NUM_RECENT_PORTS];
   int              otherIpPortsRcvd[MAX_NUM_RECENT_PORTS], otherIpPortsSent[MAX_NUM_RECENT_PORTS];
-  TrafficCounter   ipBytesSent, ipBytesRcvd, ipv6Sent, ipv6Rcvd;
+  TrafficCounter   ipv4BytesSent, ipv4BytesRcvd, ipv6BytesSent, ipv6BytesRcvd;
   TrafficCounter   tcpSentLoc, tcpSentRem, udpSentLoc, udpSentRem, icmpSent,icmp6Sent;
   TrafficCounter   tcpRcvdLoc, tcpRcvdFromRem, udpRcvdLoc, udpRcvdFromRem, icmpRcvd, icmp6Rcvd;
 
@@ -866,6 +923,7 @@ typedef struct hostTraffic {
 typedef struct domainStats {
   HostTraffic *domainHost; /* ptr to a host that belongs to the domain */
   char *clusterName;
+  int8_t known_subnet_id;
   TrafficCounter bytesSent, bytesRcvd;
   TrafficCounter tcpSent, udpSent;
   TrafficCounter icmpSent,icmp6Sent;
@@ -914,18 +972,19 @@ typedef struct ipSession {
   HostTraffic *remotePeer;          /* remote peer address                        */
   HostAddr remotePeerRealIp;        /* Real IP address (if masqueraded and known) */
   char *virtualPeerName;            /* Name of a virtual host (e.g. HTTP virtual host) */
-  u_short dport;                    /* remote peer address (port)                       */
-  time_t firstSeen;                 /* time when the session has been initiated         */
-  time_t lastSeen;                  /* time when the session has been closed            */
+  u_short dport;                    /* remote peer address (port)               */
+  time_t firstSeen;                 /* time when the session has been initiated */
+  time_t lastSeen;                  /* time when the session has been closed    */
   u_long pktSent, pktRcvd;
-  TrafficCounter bytesSent;         /* # bytes sent (initiator -> peer) [IP]            */
+  TrafficCounter bytesSent;         /* # bytes sent (initiator -> peer) [IP]    */
   TrafficCounter bytesRcvd;         /* # bytes rcvd (peer -> initiator)[IP]     */
   TrafficCounter bytesProtoSent;    /* # bytes sent (Protocol [e.g. HTTP])      */
   TrafficCounter bytesProtoRcvd;    /* # bytes rcvd (Protocol [e.g. HTTP])      */
   TrafficCounter bytesFragmentedSent;     /* IP Fragments                       */
   TrafficCounter bytesFragmentedRcvd;     /* IP Fragments                       */
   u_int minWindow, maxWindow;       /* TCP window size                          */
-  struct timeval nwLatency;         /* Network Latency                          */
+  struct timeval synTime, synAckTime, ackTime; /* Used to calcolate nw delay */
+  struct timeval clientNwDelay, serverNwDelay; /* Network Delay/Latency         */
   u_short numFin;                   /* # FIN pkts rcvd                          */
   u_short numFinAcked;              /* # ACK pkts rcvd                          */
   u_int32_t lastAckIdI2R;           /* ID of the last ACK rcvd                  */
@@ -1234,8 +1293,17 @@ typedef struct astats {
   struct astats *next;
 } AsStats;
 
+typedef struct {
+  u_int32_t address[4]; /* [0]=network, [1]=mask, [2]=broadcast, [3]=mask_v6 */    
+} NetworkStats;
+
 #define MAX_INTERFACE_STATS_QUEUE_LEN  32
 
+typedef struct optionTemplate {
+  u_int16_t templateId;
+  struct optionTemplate *next;
+} OptionTemplate;
+
 typedef struct netFlowGlobals {
   u_char netFlowDebug;
 
@@ -1265,17 +1333,19 @@ typedef struct netFlowGlobals {
     numSrcNetFlowsEntryAccepted,
     numDstNetFlowsEntryFailedBlackList, numDstNetFlowsEntryFailedWhiteList,
     numDstNetFlowsEntryAccepted;
-  u_long numNetFlowsV9TemplRcvd, numNetFlowsV9BadTemplRcvd, numNetFlowsV9UnknTemplRcvd;
+  u_long numNetFlowsV9TemplRcvd, numNetFlowsV9BadTemplRcvd, numNetFlowsV9UnknTemplRcvd,
+    numNetFlowsV9OptionFlowsRcvd;
 
   /* Stats */
   ProbeInfo probeList[MAX_NUM_PROBES];
   InterfaceStats *ifStats;
-  u_int32_t whiteNetworks[MAX_NUM_NETWORKS][4], blackNetworks[MAX_NUM_NETWORKS][4];
+  NetworkStats whiteNetworks[MAX_NUM_NETWORKS], blackNetworks[MAX_NUM_NETWORKS];
   u_short numWhiteNets, numBlackNets;
   u_int32_t flowProcessed;
   Counter flowProcessedBytes;
   HostTraffic *dummyHost;
   FlowSetV9 *templates;
+  OptionTemplate *optionTemplates;
 
   pthread_t netFlowThread;
   int threadActive;
@@ -1288,11 +1358,37 @@ typedef struct netFlowGlobals {
   PthreadMutex ifStatsQueueMutex;
   ConditionalVariable ifStatsQueueCondvar;
 #endif
-
 } NetFlowGlobals;
 
 /* *********************************** */
 
+typedef struct cpacket_counter {
+  char *name;
+  u_long bytes, packets;
+  struct cpacket_counter *next;
+} cPacketCounter;
+
+typedef struct cpacket_globals {
+  u_char cpacketDebug;
+
+  /* Flow reception */
+  int cpacketInSocket, cpacketDeviceId;
+  u_short cpacketInPort;
+  u_long numPktsRcvd;
+
+  /* Stats */
+  ProbeInfo deviceList[MAX_NUM_PROBES];
+  u_int32_t statsProcessed;
+  
+  /* Counters */
+  cPacketCounter *counter_list_head, *last_head;
+
+  pthread_t cpacketThread;
+  int threadActive;
+} cPacketGlobals;
+
+/* *********************************** */
+
 #define MAX_NUM_SFLOW_INTERFACES      4096
 
 typedef struct ifCounters {
@@ -1344,7 +1440,7 @@ typedef struct sFlowGlobals {
 
   /* Stats */
   ProbeInfo probeList[MAX_NUM_PROBES];
-  u_int32_t whiteNetworks[MAX_NUM_NETWORKS][4], blackNetworks[MAX_NUM_NETWORKS][4];
+  NetworkStats whiteNetworks[MAX_NUM_NETWORKS], blackNetworks[MAX_NUM_NETWORKS];
   u_short numWhiteNets, numBlackNets;
   u_int32_t flowProcessed;
   Counter flowProcessedBytes;
@@ -1398,7 +1494,7 @@ typedef struct ntopInterface {
   u_short samplingRate;          /* default = 1 */
   u_short droppedSamples;        /* Number of packets dropped due to sampling, since the last processed pkt */
   u_short mtuSize,               /* MTU and header, derived from DLT and table in globals-core.c */
-          headerSize;
+    headerSize;
 
   char *filter;                  /* user defined filter expression (if any) */
 
@@ -1439,7 +1535,7 @@ typedef struct ntopInterface {
    * The bytes section
    */
   TrafficCounter ethernetBytes;  /* # bytes captured */
-  TrafficCounter ipBytes;
+  TrafficCounter ipv4Bytes;
   TrafficCounter fragmentedIpBytes;
   TrafficCounter tcpBytes;
   TrafficCounter udpBytes;
@@ -1449,12 +1545,12 @@ typedef struct ntopInterface {
   TrafficCounter dlcBytes;
   TrafficCounter ipxBytes;
   TrafficCounter stpBytes;        /* Spanning Tree */
-  TrafficCounter decnetBytes;
+  TrafficCounter ipsecBytes;
   TrafficCounter netbiosBytes;
   TrafficCounter arpRarpBytes;
   TrafficCounter atalkBytes;
   TrafficCounter egpBytes;
-  TrafficCounter osiBytes;
+  TrafficCounter greBytes;
   TrafficCounter ipv6Bytes;
   TrafficCounter icmp6Bytes;
   TrafficCounter otherBytes;
@@ -1541,7 +1637,13 @@ typedef struct ntopInterface {
   struct hostTraffic** fcTrafficMatrixHosts; /* Subnet traffic Matrix Hosts */
 
   NetFlowGlobals *netflowGlobals;  /* NetFlow */
-  SflowGlobals *sflowGlobals;      /* sFlow */
+  SflowGlobals   *sflowGlobals;    /* sFlow */
+  cPacketGlobals *cpacketGlobals;  /* cPacket */
+
+  /* ********************* */
+  
+  /* The variable below is used to collect stats concerning interface subnets */
+  HostTraffic networkHost[MAX_NUM_INTERFACE_NETWORKS];
 } NtopInterface;
 
 /* *********************************** */
@@ -1975,7 +2077,6 @@ typedef struct _userPref {
   bool stickyHosts;             /* -c | --sticky-hosts */
   bool daemonMode;              /* -d | --daemon */
   int  maxNumLines;             /* -e | --max-table-rows */
-  char *rFileName;              /* -f | --traffic-dump-file */
   bool trackOnlyLocalHosts;     /* -g | --track-local-hosts */
   char *devices;                /* -i | --interface */
   bool enableOtherPacketDump;   /* -j | --create-other-packets */
@@ -2038,7 +2139,6 @@ typedef struct _userPref {
 
   char *instance;               /* --instance '140' */
   char *logo;
-
   bool disableStopcap;          /* --disable-stopcap '142' */
 
   bool disableInstantSessionPurge; /* --disable-instantsessionpurge '144' */
@@ -2046,12 +2146,11 @@ typedef struct _userPref {
   bool printIpOnly;             /* --no-fc '148' */
   bool noInvalidLunDisplay;     /* --no-invalid-lun '149' */
   bool disableMutexExtraInfo;   /* --disable-mutexextrainfo '145' */
-
   bool skipVersionCheck;        /* --skip-version-check '150' */
+  char *knownSubnets;           /* --known-subnets '151' */
 } UserPref;
 
 typedef struct ntopGlobals {
-
   /* How is ntop run? */
 
   char *program_name;      /* The name the program was run with, stripped of any leading path */
@@ -2084,7 +2183,7 @@ typedef struct ntopGlobals {
 #endif
   char *dbPath;                 /* 'P' */
   char *spoolPath;              /* 'Q' */
-
+  struct fileList *pcap_file_list; /* --pcap-file-list */
   /* Other flags (these could set via command line options one day) */
   bool enableFragmentHandling;
 
@@ -2097,9 +2196,9 @@ typedef struct ntopGlobals {
   bool haveASN, haveVLANs;
 
   /* Physical and Logical network interfaces */
-
+  pcap_if_t *allDevs;      /* all devices available for pcap_open */
   u_short numDevices;      /* total network interfaces */
-  NtopInterface *device;   /* pointer to the table of Network interfaces */
+  NtopInterface *device;   /* pointer to the network interfaces table */
 
   /* Database */
   GDBM_FILE dnsCacheFile, pwFile, addressQueueFile, prefsFile, macPrefixFile, fingerprintFile;
@@ -2164,8 +2263,8 @@ typedef struct ntopGlobals {
    * Control mutexes
    */
   PthreadMutex gdbmMutex;
-  PthreadMutex tcpSessionsMutex;
-  PthreadMutex fcSessionsMutex;
+  PthreadMutex tcpSessionsMutex[NUM_SESSION_MUTEXES];
+  PthreadMutex fcSessionsMutex; /* One mutex should be enough */
   PthreadMutex purgePortsMutex;
   PthreadMutex securityItemsMutex;
 #ifdef FORPRENPTL
@@ -2288,9 +2387,13 @@ typedef struct ntopGlobals {
   u_short *mtuSize, *headerSize;
 
   /* (Pseudo) Local Networks */
-  u_int32_t localNetworks[MAX_NUM_NETWORKS][4]; /* [0]=network, [1]=mask, [2]=broadcast, [3]=mask_v6 */
+  NetworkStats localNetworks[MAX_NUM_NETWORKS];
   u_short numLocalNetworks;
 
+  /* All known Networks */
+  NetworkStats subnetStats[MAX_NUM_INTERFACE_NETWORKS];
+  u_short numKnownSubnets;  
+
 #if defined(MEMORY_DEBUG) && (MEMORY_DEBUG == 3)
   size_t allocatedMemory;
 #endif
@@ -2309,7 +2412,7 @@ typedef struct ntopGlobals {
   int numChildren;
 
   /* rrd */
-  char *rrdPath;
+  char *rrdPath, *rrdVolatilePath;
   mode_t rrdDirectoryPermissions, rrdUmask;
 
   /* http.c */
@@ -2365,14 +2468,6 @@ typedef struct ntopGlobals {
     numVendorLookupFoundMulticast,
     numVendorLookupFoundLAA;
 
-  /* i18n */
-#ifdef MAKE_WITH_I18N
-  char *defaultLanguage;
-  int  maxSupportedLanguages;
-  char *supportedLanguages[MAX_LANGUAGES_SUPPORTED];
-  char *strftimeFormat[MAX_LANGUAGES_SUPPORTED];
-#endif
-
   /* Country flags */
   IPNode *countryFlagHead;
   int  ipCountryMem, ipCountryCount;
@@ -2412,5 +2507,8 @@ typedef struct ntopGlobals {
   u_short experimentalFlagSet;  /* Is the 'experimental' flag set? */
 #endif
 
+  u_int8_t  calculateEfficiency;
+  /* If the traffic is divided in cells (e.g. ATM, cell payload is 47 bytes) this is the cell lenght */
+  u_int16_t cellLength; 
 } NtopGlobals;
 
