@@ -25,8 +25,6 @@
 
 #include "ntop.h"
 
-#ifndef EMBEDDED
-
 #define _GRAPH_C_
 #include "globals-report.h"
 
@@ -40,37 +38,37 @@ struct bar_elements {
 /* ******************************************************************* */
 
 static void send_graph_header(u_char is_pie) {
-sendString("<HTML>\n"
-"<HEAD>\n"
-"<META HTTP-EQUIV=REFRESH CONTENT=30>\n"
-"<META HTTP-EQUIV=Pragma CONTENT=no-cache>\n"
-"<META HTTP-EQUIV=Cache-Control CONTENT=no-cache>\n"
-"<script type=\"text/javascript\" src=\"/MochiKit/MochiKit.js\"></script>\n"
-"<script type=\"text/javascript\" src=\"/PlotKit/excanvas.js\"></script>\n"
-"<script type=\"text/javascript\" src=\"/PlotKit/Base.js\"></script>\n"
-"<script type=\"text/javascript\" src=\"/PlotKit/Layout.js\"></script>\n"
-"<script type=\"text/javascript\" src=\"/PlotKit/Canvas.js\"></script>\n"
-"<script type=\"text/javascript\" src=\"/PlotKit/SweetCanvas.js\"></script>\n"
-"<script type=\"text/javascript\" src=\"/PlotKit/EasyPlot.js\"></script>\n"
-"<style type=\"text/css\">\n"
-"body {\n"
-	   "font-family: \"Lucida Grande\", \"Tahoma\", \"Verdana\", \"Sans\", \"sans-serif\";\n"
-	   "font-size: 12px;\n"
-"}\n"
-"</style>\n"
-"<script type=\"text/javascript\">\n"
-"//<![CDATA[\n"
-"function drawchart() {\n"
-"   var hasCanvas = CanvasRenderer.isSupported();\n"
-"\n"
-"   var opts = {\n"
-);
-
-if(is_pie) sendString("   \"pieRadius\": 0.42,	  \n");
-
- sendString("    \"colorScheme\": PlotKit.Base.palette(PlotKit.Base.baseColors()[0]),\n");
- if(is_pie) sendString("   \"backgroundColor\": PlotKit.Base.baseColors()[0].lighterColorWithLevel(1),\n" );
- sendString("   \"xTicks\": [");
+  sendString("<HTML>\n"
+	     "<HEAD>\n"
+	     "<META HTTP-EQUIV=REFRESH CONTENT=30>\n"
+	     "<META HTTP-EQUIV=Pragma CONTENT=no-cache>\n"
+	     "<META HTTP-EQUIV=Cache-Control CONTENT=no-cache>\n"
+	     "<script type=\"text/javascript\" src=\"/MochiKit/MochiKit.js\"></script>\n"
+	     "<script type=\"text/javascript\" src=\"/PlotKit/excanvas.js\"></script>\n"
+	     "<script type=\"text/javascript\" src=\"/PlotKit/Base.js\"></script>\n"
+	     "<script type=\"text/javascript\" src=\"/PlotKit/Layout.js\"></script>\n"
+	     "<script type=\"text/javascript\" src=\"/PlotKit/Canvas.js\"></script>\n"
+	     "<script type=\"text/javascript\" src=\"/PlotKit/SweetCanvas.js\"></script>\n"
+	     "<script type=\"text/javascript\" src=\"/PlotKit/EasyPlot.js\"></script>\n"
+	     "<style type=\"text/css\">\n"
+	     "body {\n"
+	     "font-family: \"Lucida Grande\", \"Tahoma\", \"Verdana\", \"Sans\", \"sans-serif\";\n"
+	     "font-size: 12px;\n"
+	     "}\n"
+	     "</style>\n"
+	     "<script type=\"text/javascript\">\n"
+	     "//<![CDATA[\n"
+	     "function drawchart() {\n"
+	     "   var hasCanvas = CanvasRenderer.isSupported();\n"
+	     "\n"
+	     "   var opts = {\n"
+	     );
+  
+  if(is_pie) sendString("   \"pieRadius\": 0.42,	  \n");
+  
+  sendString("    \"colorScheme\": PlotKit.Base.palette(PlotKit.Base.baseColors()[0]),\n");
+  if(is_pie) sendString("   \"backgroundColor\": PlotKit.Base.baseColors()[0].lighterColorWithLevel(1),\n" );
+  sendString("   \"xTicks\": [");
 }
  
 /**********************************************************/
@@ -153,9 +151,9 @@ static void build_chart(u_char is_pie, char *the_type, int num, float *p,
   send_graph_footer(the_type, width, height);
 }
 
-#define build_pie(a, b, c) build_chart(1, "pie", a, b, c, 350, 200)
-#define build_line(a, b, c) build_chart(0, "line", a, b, c, 600, 200)
-#define build_bar(a, b, c) build_chart(0, "bar", a, b, c, 600, 200)
+#define build_pie(a, b, c)  build_chart(1, "pie", a, b, c, 350, 200)
+#define build_line(a, b, c) build_chart(0, "line", a, b, c, 350, 200)
+#define build_bar(a, b, c)  build_chart(0, "bar", a, b, c, 600, 200)
 
 /* ******************************************************************* */
 
@@ -171,15 +169,17 @@ void hostTrafficDistrib(HostTraffic *theHost, short dataSent) {
   if(dataSent) {
     totTraffic.value = theHost->tcpSentLoc.value+theHost->tcpSentRem.value+
       theHost->udpSentLoc.value+theHost->udpSentRem.value+
-      theHost->icmpSent.value+theHost->ipv6Sent.value;
+      theHost->icmpSent.value+theHost->ipv6BytesSent.value+
+      theHost->greSent.value+theHost->ipsecSent.value;
     
     if(theHost->nonIPTraffic != NULL)
       totTraffic.value += theHost->nonIPTraffic->stpSent.value+
-	theHost->nonIPTraffic->ipxSent.value+theHost->nonIPTraffic->osiSent.value+
+	theHost->nonIPTraffic->ipxSent.value+
 	theHost->nonIPTraffic->dlcSent.value+
-	theHost->nonIPTraffic->arp_rarpSent.value+theHost->nonIPTraffic->decnetSent.value+
+	theHost->nonIPTraffic->arp_rarpSent.value+
 	theHost->nonIPTraffic->appletalkSent.value+
-	theHost->nonIPTraffic->netbiosSent.value+theHost->nonIPTraffic->otherSent.value;
+	theHost->nonIPTraffic->netbiosSent.value+
+	theHost->nonIPTraffic->otherSent.value;
 
     idx = 0;
     while(protoList != NULL) {
@@ -190,13 +190,17 @@ void hostTrafficDistrib(HostTraffic *theHost, short dataSent) {
   } else {
     totTraffic.value = theHost->tcpRcvdLoc.value+theHost->tcpRcvdFromRem.value+
       theHost->udpRcvdLoc.value+theHost->udpRcvdFromRem.value+
-      theHost->icmpRcvd.value+theHost->ipv6Rcvd.value;
+      theHost->icmpRcvd.value+theHost->ipv6BytesRcvd.value+
+      theHost->greRcvd.value+theHost->ipsecRcvd.value;
 
     if(theHost->nonIPTraffic != NULL)
       totTraffic.value += theHost->nonIPTraffic->stpRcvd.value
-	+theHost->nonIPTraffic->ipxRcvd.value+theHost->nonIPTraffic->osiRcvd.value+theHost->nonIPTraffic->dlcRcvd.value+
-	theHost->nonIPTraffic->arp_rarpRcvd.value+theHost->nonIPTraffic->decnetRcvd.value+theHost->nonIPTraffic->appletalkRcvd.value+
-	theHost->nonIPTraffic->netbiosRcvd.value+theHost->nonIPTraffic->otherRcvd.value;
+	+theHost->nonIPTraffic->ipxRcvd.value
+	+theHost->nonIPTraffic->dlcRcvd.value
+	+theHost->nonIPTraffic->arp_rarpRcvd.value
+	+theHost->nonIPTraffic->appletalkRcvd.value
+	+theHost->nonIPTraffic->netbiosRcvd.value
+	+theHost->nonIPTraffic->otherRcvd.value;
     
     idx = 0;
     while(protoList != NULL) {
@@ -225,11 +229,21 @@ void hostTrafficDistrib(HostTraffic *theHost, short dataSent) {
 	if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "ICMP";
       }
 
-      if(theHost->ipv6Sent.value > 0) {
-	p[num] = (float)((100*theHost->ipv6Sent.value)/totTraffic.value);
+      if(theHost->ipv6BytesSent.value > 0) {
+	p[num] = (float)((100*theHost->ipv6BytesSent.value)/totTraffic.value);
 	if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "IPv6";
       }
 
+	if(theHost->greSent.value > 0) {
+	  p[num] = (float)((100*theHost->greSent.value)/totTraffic.value);
+	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "GRE";
+	}
+
+	if(theHost->ipsecSent.value > 0) {
+	  p[num] = (float)((100*theHost->ipsecSent.value)/totTraffic.value);
+	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "IPSEC";
+	}
+
       if(theHost->nonIPTraffic != NULL) {
 	if(theHost->nonIPTraffic->stpSent.value > 0) {
 	  p[num] = (float)((100*theHost->nonIPTraffic->stpSent.value)/totTraffic.value);
@@ -246,21 +260,11 @@ void hostTrafficDistrib(HostTraffic *theHost, short dataSent) {
 	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "DLC";
 	}
 
-	if(theHost->nonIPTraffic->osiSent.value > 0) {
-	  p[num] = (float)((100*theHost->nonIPTraffic->osiSent.value)/totTraffic.value);
-	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "OSI";
-	}
-
 	if(theHost->nonIPTraffic->arp_rarpSent.value > 0) {
 	  p[num] = (float)((100*theHost->nonIPTraffic->arp_rarpSent.value)/totTraffic.value);
 	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "(R)ARP";
 	}
 
-	if(theHost->nonIPTraffic->decnetSent.value > 0) {
-	  p[num] = (float)((100*theHost->nonIPTraffic->decnetSent.value)/totTraffic.value);
-	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "DECNET";
-	}
-
 	if(theHost->nonIPTraffic->appletalkSent.value > 0) {
 	  p[num] = (float)((100*theHost->nonIPTraffic->appletalkSent.value)/totTraffic.value);
 	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "AppleTalk";
@@ -294,11 +298,21 @@ void hostTrafficDistrib(HostTraffic *theHost, short dataSent) {
 	if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "ICMP";     
       }
 
-      if(theHost->ipv6Rcvd.value > 0) {
-	p[num] = (float)((100*theHost->ipv6Rcvd.value)/totTraffic.value);
+      if(theHost->ipv6BytesRcvd.value > 0) {
+	p[num] = (float)((100*theHost->ipv6BytesRcvd.value)/totTraffic.value);
 	if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "IPv6";
       }
 
+      if(theHost->greRcvd.value > 0) {
+	p[num] = (float)((100*theHost->greRcvd.value)/totTraffic.value);
+	if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "GRE";
+      }
+      
+      if(theHost->ipsecRcvd.value > 0) {
+	p[num] = (float)((100*theHost->ipsecRcvd.value)/totTraffic.value);
+	if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "IPSEC";
+      }
+      
       if(theHost->nonIPTraffic != NULL) {
 	if(theHost->nonIPTraffic->stpRcvd.value > 0) {
 	  p[num] = (float)((100*theHost->nonIPTraffic->stpRcvd.value)/totTraffic.value);
@@ -315,21 +329,11 @@ void hostTrafficDistrib(HostTraffic *theHost, short dataSent) {
 	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "DLC";
 	}
 
-	if(theHost->nonIPTraffic->osiRcvd.value > 0) {
-	  p[num] = (float)((100*theHost->nonIPTraffic->osiRcvd.value)/totTraffic.value);
-	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "OSI";
-	}
-
 	if(theHost->nonIPTraffic->arp_rarpRcvd.value > 0) {
 	  p[num] = (float)((100*theHost->nonIPTraffic->arp_rarpRcvd.value)/totTraffic.value);
 	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "(R)ARP";
 	}
 
-	if(theHost->nonIPTraffic->decnetRcvd.value > 0) {
-	  p[num] = (float)((100*theHost->nonIPTraffic->decnetRcvd.value)/totTraffic.value);
-	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "DECNET";
-	}
-
 	if(theHost->nonIPTraffic->appletalkRcvd.value > 0) {
 	  p[num] = (float)((100*theHost->nonIPTraffic->appletalkRcvd.value)/totTraffic.value);
 	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "AppleTalk";
@@ -455,7 +459,7 @@ void hostTimeTrafficDistribution(HostTraffic *theHost, short dataSent) {
       p[num] = traf.value;
       switch(i) {
       case 0:
-	lbl[num++] = "12PM-1AM";
+	lbl[num++] = "12-1AM";
 	break;
       case 1:
 	lbl[num++] = "1-2AM";
@@ -488,10 +492,10 @@ void hostTimeTrafficDistribution(HostTraffic *theHost, short dataSent) {
 	lbl[num++] = "10-11AM";
 	break;
       case 11:
-	lbl[num++] = "11-12AM";
+	lbl[num++] = "11AM-12PM";
 	break;
       case 12:
-	lbl[num++] = "12AM-1PM";
+	lbl[num++] = "12-1PM";
 	break;
       case 13:
 	lbl[num++] = "1-2PM";
@@ -524,7 +528,7 @@ void hostTimeTrafficDistribution(HostTraffic *theHost, short dataSent) {
 	lbl[num++] = "10-11PM";
 	break;
       case 23:
-	lbl[num++] = "11-12PM";
+	lbl[num++] = "11PM-12AM";
 	break;
       }
     }
@@ -549,11 +553,11 @@ void hostTotalFragmentDistrib(HostTraffic *theHost, short dataSent) {
   TrafficCounter totFragmentedTraffic, totTraffic;
 
   if(dataSent) {
-    totTraffic.value = theHost->ipBytesSent.value;
+    totTraffic.value = theHost->ipv4BytesSent.value;
     totFragmentedTraffic.value = theHost->tcpFragmentsSent.value+theHost->udpFragmentsSent.value
       +theHost->icmpFragmentsSent.value;
   } else {
-    totTraffic.value = theHost->ipBytesRcvd.value;
+    totTraffic.value = theHost->ipv4BytesRcvd.value;
     totFragmentedTraffic.value = theHost->tcpFragmentsRcvd.value+theHost->udpFragmentsRcvd.value
       +theHost->icmpFragmentsRcvd.value;
   }
@@ -593,11 +597,22 @@ void hostIPTrafficDistrib(HostTraffic *theHost, short dataSent) {
   diffTraffic.value = 0;
 
   if(dataSent)
-    totalIPTraffic.value = theHost->ipBytesSent.value;
+    totalIPTraffic.value = theHost->ipv4BytesSent.value;
   else
-    totalIPTraffic.value = theHost->ipBytesRcvd.value;
+    totalIPTraffic.value = theHost->ipv4BytesRcvd.value;
 
   if(totalIPTraffic.value > 0) {
+    if(dataSent)
+      traffic.value = theHost->ipsecSent.value;    
+    else
+      traffic.value = theHost->ipsecRcvd.value;
+ 
+    if(traffic.value > 0) {
+      p[num] = (float)((100*traffic.value)/totalIPTraffic.value);
+      diffTraffic.value += traffic.value;
+      lbl[num++] = "IPSEC";
+    }
+
     for(i=0; i<myGlobals.numIpProtosToMonitor; i++) {
       if(theHost->protoIPTrafficInfos[i]) {
 	if(dataSent)
@@ -885,7 +900,7 @@ void drawTrafficPie(void) {
 
   if(myGlobals.device[myGlobals.actualReportDeviceId].ethernetBytes.value == 0) return;
 
-  ip.value = myGlobals.device[myGlobals.actualReportDeviceId].ipBytes.value;
+  ip.value = myGlobals.device[myGlobals.actualReportDeviceId].ipv4Bytes.value;
 
   p[0] = ip.value*100/myGlobals.device[myGlobals.actualReportDeviceId].ethernetBytes.value; num++;
   p[1] = 100-p[0];
@@ -900,13 +915,10 @@ void drawTrafficPie(void) {
 /* ************************ */
 
 void drawGlobalProtoDistribution(void) {
-  TrafficCounter ip;
   float p[256]; /* Fix courtesy of Andreas Pfaller <apfaller@yahoo.com.au> */
   char	*lbl[16];
   int idx = 0;
 
-  ip.value = myGlobals.device[myGlobals.actualReportDeviceId].ipBytes.value;
-
   if(myGlobals.device[myGlobals.actualReportDeviceId].tcpBytes.value > 0) {
     p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].tcpBytes.value; lbl[idx] = "TCP";  idx++; }
   if(myGlobals.device[myGlobals.actualReportDeviceId].udpBytes.value > 0) {
@@ -921,14 +933,14 @@ void drawGlobalProtoDistribution(void) {
     p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].dlcBytes.value; lbl[idx] = "DLC"; idx++; }
   if(myGlobals.device[myGlobals.actualReportDeviceId].ipxBytes.value > 0) {
     p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].ipxBytes.value; lbl[idx] = "IPX"; idx++; }
-  if(myGlobals.device[myGlobals.actualReportDeviceId].decnetBytes.value > 0) {
-    p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].decnetBytes.value;lbl[idx] = "Decnet";  idx++; }
+  if(myGlobals.device[myGlobals.actualReportDeviceId].ipsecBytes.value > 0) {
+    p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].ipsecBytes.value;lbl[idx] = "IPsec";  idx++; }
   if(myGlobals.device[myGlobals.actualReportDeviceId].atalkBytes.value > 0) {
     p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].atalkBytes.value; lbl[idx] = "AppleTalk"; idx++; }
   if(myGlobals.device[myGlobals.actualReportDeviceId].netbiosBytes.value > 0) {
     p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].netbiosBytes.value; lbl[idx] = "NetBios"; idx++; }
-  if(myGlobals.device[myGlobals.actualReportDeviceId].osiBytes.value > 0) {
-    p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].osiBytes.value; lbl[idx] = "OSI"; idx++; }
+  if(myGlobals.device[myGlobals.actualReportDeviceId].greBytes.value > 0) {
+    p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].greBytes.value; lbl[idx] = "GRE"; idx++; }
   if(myGlobals.device[myGlobals.actualReportDeviceId].ipv6Bytes.value > 0) {
     p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].ipv6Bytes.value; lbl[idx] = "IPv6"; idx++; }
   if(myGlobals.device[myGlobals.actualReportDeviceId].stpBytes.value > 0) {
@@ -971,7 +983,8 @@ void drawGlobalIpProtoDistribution(void) {
   ProtocolsList *protoList = myGlobals.ipProtosList;
   float total, partialTotal = 0;
 
-  total = (float)myGlobals.device[myGlobals.actualReportDeviceId].ipBytes.value;
+  total = (float)myGlobals.device[myGlobals.actualReportDeviceId].ipv4Bytes.value
+    + (float)myGlobals.device[myGlobals.actualReportDeviceId].ipv6Bytes.value;
 
   if(myGlobals.device[myGlobals.actualReportDeviceId].ipProtosList) {
     while(protoList != NULL) {
@@ -1554,6 +1567,3 @@ void drawVsanDomainTrafficDistribution(u_short vsanId, u_char dataSent) {
 
   build_pie(idx, p, lbl);
 }
-
-
-#endif /* EMBEDDED */
