@@ -36,15 +36,20 @@
 #define SA6(saddr)      ((struct sockaddr_in6 *)saddr)
 #define IN6(saddr)      (&SA6(saddr)->sin6_addr)
 
+/* ************************************************* */
 
 static struct in6_addr *in6_cpy(struct in6_addr *dst, struct in6_addr *src) {
   return memcpy(dst, src, sizeof(struct in6_addr));
 }
 
+/* ************************************************* */
+
 static struct in_addr *in4_cpy(struct in_addr *dst, struct in_addr *src) {
   return memcpy(dst, src, sizeof(struct in_addr));
 }
 
+/* ************************************************* */
+
 static void str2in6_addr(char *str, struct in6_addr *addr) {
   int i;
   unsigned int x;
@@ -55,6 +60,8 @@ static void str2in6_addr(char *str, struct in6_addr *addr) {
   }
 }
 
+/* ************************************************* */
+
 static int prefixlen(void *val, int size) {
   unsigned char *name = (unsigned char *)val;
   int byte, bit, plen = 0;
@@ -328,7 +335,7 @@ struct iface_handler *iface_new(void) {
 
   /* Allocate memory for iface handler
    */
-  if (! (hdlr = (struct iface_handler *)calloc(1,sizeof(struct iface_handler)))){
+  if(!(hdlr = (struct iface_handler *)calloc(1, sizeof(struct iface_handler)))){
     errno = ENOMEM;
     goto failed;
   }
@@ -348,7 +355,7 @@ struct iface_handler *iface_new(void) {
       if (strncmp(itf->name, ifname,IFNAMSIZ) == 0){
 	/* update addresses*/
 	for (it = itf->addrs;it->next != NULL ; it = it->next);
-	ia = (struct iface_addr *) malloc(sizeof(struct iface_addr));
+	ia = (struct iface_addr *)malloc(sizeof(struct iface_addr));
 	ia->family = AF_INET6;
 	ia->ifi = itf;
 	in6_cpy(&ia->af.inet6.addr, &addr);
@@ -747,10 +754,6 @@ void sanitizeIfName(char *deviceDescr) {
 /* ********************************************************************** */
 
 void calculateUniqueInterfaceName(int deviceId) {
-#ifdef WIN32
-  int i;
-#endif
-
   if(myGlobals.device[deviceId].uniqueIfName) 
     free(myGlobals.device[deviceId].uniqueIfName);
 
@@ -762,10 +765,15 @@ void calculateUniqueInterfaceName(int deviceId) {
 
 #ifdef HAVE_SNMP
 
+#undef NETSNMP_USE_INLINE
+#define NETSNMP_BROKEN_INLINE
+
 #include <net-snmp/net-snmp-config.h>
 #include <net-snmp/net-snmp-includes.h>
 #include <string.h>
 
+
+
 #ifndef min
 #define min(a,b) (a<b ? a : b)
 #endif
@@ -778,10 +786,8 @@ char* getIfName(char *hostname, char *community, int ifIdx,
   char buf[64];
   oid anOID[MAX_OID_LEN];
   size_t anOID_len = MAX_OID_LEN;
-
   struct variable_list *vars;
   int status;
-  int count=1;
 
   ifName_buf[0] = '\0';
 
@@ -819,8 +825,8 @@ char* getIfName(char *hostname, char *community, int ifIdx,
   read_objid(buf, anOID, &anOID_len); snmp_add_null_var(pdu, anOID, anOID_len);
 
   traceEvent(CONST_TRACE_NOISY, 
-	     "Reading SNMP interface name: [host=%s][community=%s][%s]",
-	     hostname, community, buf);
+	     "Reading SNMP interface name: [host=%s][community=%s][ifIdx=%d]",
+	     hostname, community, ifIdx);
   /*
    * Send the Request out.
    */
