@@ -152,6 +152,13 @@ void usage(FILE * fp) {
 #ifdef MAKE_WITH_SSLWATCHDOG_RUNTIME
   fprintf(fp, "    [--ssl-watchdog]                                      %sUse ssl watchdog (NS6 problem)\n", newLine);
 #endif
+  fprintf(fp, "    [--known-subnets]                                     %sList of known subnets (separated by ,)\n", newLine);
+  fprintf(fp, "                                                          %sIf the argument starts with @ it is assumed it is a file path\n", newLine);
+  fprintf(fp, "                                                          %sE.g. 192.168.0.0/14=home,172.16.0.0/16=private\n", newLine);
+  fprintf(fp, "    [--pcap-file-list] <filename>                         %sSpecify a filename containing a list\n"
+	  "                                                              %sof pcap files to read.\n"
+	  "                                                              %sIf you use this flag the -i option will be\n"
+	  "                                                              %signored.\n", newLine, newLine, newLine, newLine);
 
  fprintf(fp, "\n"
 	 "NOTE\n"
@@ -192,7 +199,7 @@ static void verifyOptions (void) {
      * Verify we're running as root, unless we are reading data from a file
      */
 
-    if(myGlobals.runningPref.rFileName != NULL) {
+    if(myGlobals.pcap_file_list != NULL) {
       return;
     }
 
@@ -313,27 +320,17 @@ int main(int argc, char *argv[]) {
 #endif
   int i, rc, userSpecified;
   char ifStr[196] = {0};
-  time_t lastTime, endTime;
+  time_t lastTime;
   char *cmdLineBuffer, *readBuffer, *readBufferWork;
   FILE *fd;
   struct stat fileStat;
   int effective_argc;
   char **effective_argv;
+  time_t endTime;
   char main_buf[LEN_GENERAL_WORK_BUFFER];
-#ifndef WIN32
   char lib[LEN_GENERAL_WORK_BUFFER],
        env[LEN_GENERAL_WORK_BUFFER],
        buf[LEN_GENERAL_WORK_BUFFER];
-#endif
-
-  /*
-  unsigned long driveSerial;
-  if(get_serial("C:\\", &driveSerial))
-	  printf("C:\\ Serial Number: %u\n", driveSerial);
-  else
-printf("Unable to read serial number\n");
-		exit(0);
-		*/
 
 /* Don't move this below nor above */
 #if defined(MEMORY_DEBUG) && (MEMORY_DEBUG == 1)
@@ -448,6 +445,11 @@ printf("Unable to read serial number\n");
 
       printf("   Processing file %s for parameters...\n", &argv[i][1]);
 
+      if(i > 1)
+	safe_strncat(cmdLineBuffer, LEN_CMDLINE_BUFFER, " '");
+      else
+	safe_strncat(cmdLineBuffer, LEN_CMDLINE_BUFFER, " ");
+
       for (;;) {
 	readBufferWork = fgets(readBuffer, min(LEN_FGETS_BUFFER, fileStat.st_size), fd);
 	/* On EOF, we're finished */
@@ -470,7 +472,7 @@ printf("Unable to read serial number\n");
 	 */
 	readBufferWork = strchr(readBuffer, '\n');
 	if(readBufferWork != NULL) {
-	  readBufferWork[0] = ' ';
+	  readBufferWork[0] = (i == 1) ? ' ' : ',';
 	  readBufferWork[1] = '\0';
 	}
 
@@ -488,6 +490,11 @@ printf("Unable to read serial number\n");
       }
 
       fclose(fd);
+
+      if(i > 1)
+	safe_strncat(cmdLineBuffer, LEN_CMDLINE_BUFFER, "' ");
+      else
+	safe_strncat(cmdLineBuffer, LEN_CMDLINE_BUFFER, " ");
     }
   }
   free(readBuffer);
@@ -498,6 +505,15 @@ printf("Unable to read serial number\n");
       cmdLineBuffer[strlen(cmdLineBuffer)-1] = '\0';
   }
 
+#ifdef WIN32
+  {
+	int i;
+
+	for(i=0; i<strlen(cmdLineBuffer); i++)
+		if(cmdLineBuffer[i] == '\\') cmdLineBuffer[i] = '/';
+  }
+#endif
+
   effective_argv = buildargv(cmdLineBuffer); /* Build a new argv[] from the string */
   free(cmdLineBuffer);
 
@@ -570,7 +586,7 @@ printf("Unable to read serial number\n");
 
   /* ******************************* */
 
-  if(myGlobals.runningPref.rFileName != NULL)
+  if(myGlobals.pcap_file_list != NULL)
     strncpy(ifStr, CONST_PCAP_NW_INTERFACE_FILE, sizeof(ifStr));
   else {
     ifStr[0] = '\0';
@@ -635,10 +651,8 @@ printf("Unable to read serial number\n");
    */
   startSniffer();
 
-#ifndef WIN32
-
+// #ifndef WIN32
   while(myGlobals.ntopRunState == FLAG_NTOPSTATE_RUN) {
-
     ntopSleepWhileSameState(PARM_SLEEP_LIMIT);
 
     /* Periodic recheck of the version status */
@@ -646,7 +660,6 @@ printf("Unable to read serial number\n");
        (time(NULL) > myGlobals.checkVersionStatusAgain) &&
        (myGlobals.ntopRunState == FLAG_NTOPSTATE_RUN))
       checkVersion(NULL);
-
   }
 
   traceEvent(CONST_TRACE_INFO, "THREADMGMT[t%lu]: Main thread shutting down", pthread_self());
@@ -667,7 +680,14 @@ printf("Unable to read serial number\n");
   traceEvent(CONST_TRACE_INFO, "        ntop is shutdown...        ");
   traceEvent(CONST_TRACE_INFO, "===================================");
 
+  /*
+#else
+  if(myGlobals.pcap_file_list != NULL) {
+  while(1) 
+  sleep(30);
+  }
 #endif
+*/
 
   return(0);
 }
