@@ -42,6 +42,8 @@ static void printMutexInfo(PthreadMutex *mutexId, char *mutexName) {
 	     mutexId->maxLockedDuration);
 }
 
+/* *************************** */
+
 #ifndef WIN32
 void handleSigHup(int signalId _UNUSED_) {
   int i;
@@ -62,7 +64,9 @@ void handleSigHup(int signalId _UNUSED_) {
   if(myGlobals.runningPref.numericFlag == 0)
     printMutexInfo(&myGlobals.addressResolutionMutex, "myGlobals.addressResolutionMutex");
 
-  (void)signal(SIGHUP,  handleSigHup);
+  handleKnownAddresses(myGlobals.runningPref.knownSubnets);
+
+  (void)signal(SIGHUP, handleSigHup);
 }
 
 #endif /* WIN32 */
@@ -78,7 +82,7 @@ void* pcapDispatch(void *_i) {
 	     pthread_self(), myGlobals.device[i].humanFriendlyName, getpid());
 
   /* Reset stats before to start (needed by modern libpcap versions) */
-  if(myGlobals.runningPref.rFileName == NULL) {
+  if(myGlobals.pcap_file_list == NULL) {
     pcap_stats(myGlobals.device[i].pcapPtr, &pcapStats);
     myGlobals.device[i].initialPcapDroppedPkts.value = pcapStats.ps_drop;
   }
@@ -86,8 +90,6 @@ void* pcapDispatch(void *_i) {
   traceEvent(CONST_TRACE_INFO, "THREADMGMT[t%lu]: NPS(%s): pcapDispatch thread running [p%d]",
 	     pthread_self(), myGlobals.device[i].humanFriendlyName, getpid());
 
-  /* Skip ntopSleepUntilStateRUN(), just start processing packets as soon as this starts */
-
   for(;myGlobals.ntopRunState <= FLAG_NTOPSTATE_RUN;) {
     rc = pcap_dispatch(myGlobals.device[i].pcapPtr, -1, queuePacket, (u_char*)_i);
 
@@ -101,10 +103,38 @@ void* pcapDispatch(void *_i) {
 		   pcap_geterr(myGlobals.device[i].pcapPtr));
       break;
     } else if(rc == 0) {
-      if(myGlobals.runningPref.rFileName != NULL) {
+      if(myGlobals.pcap_file_list != NULL) {
 	traceEvent(CONST_TRACE_INFO, "pcap_loop (%s) returned %d [No more packets to read]",
 		   myGlobals.device[i].humanFriendlyName, rc);
-	break; /* No more packets to read */
+      reopen_pcap:	
+	if(myGlobals.pcap_file_list->next != NULL) {
+	  struct fileList *fl = myGlobals.pcap_file_list;
+	  
+	  myGlobals.pcap_file_list = myGlobals.pcap_file_list->next;
+	  free(fl->fileName); free(fl);
+
+	  if(myGlobals.pcap_file_list != NULL) {
+	    char ebuf[CONST_SIZE_PCAP_ERR_BUF];
+
+	    if(myGlobals.device[i].pcapPtr) pcap_close(myGlobals.device[i].pcapPtr);
+	    myGlobals.device[i].pcapPtr  = pcap_open_offline(myGlobals.pcap_file_list->fileName, ebuf);
+	    
+	    if(myGlobals.device[i].pcapPtr == NULL) {
+	      traceEvent(CONST_TRACE_ERROR, "pcap_open_offline(%s): '%s'",
+			 myGlobals.pcap_file_list->fileName, ebuf);
+	      goto reopen_pcap;
+	    } else {
+	      if(myGlobals.device[i].humanFriendlyName != NULL) free(myGlobals.device[i].humanFriendlyName);
+	      myGlobals.device[i].humanFriendlyName = strdup(myGlobals.pcap_file_list->fileName);
+	      calculateUniqueInterfaceName(0);
+	      traceEvent(CONST_TRACE_INFO, "pcap_loop (%s) : reading packets from file %s",
+			 myGlobals.device[i].humanFriendlyName, myGlobals.pcap_file_list->fileName);
+	      myGlobals.device[i].datalink = pcap_datalink(myGlobals.device[i].pcapPtr);
+	    }
+	  } else
+	    break; /* No more packets to read */
+	} else	
+	  break; /* No more packets to read */
       }
     }
   }
@@ -180,7 +210,6 @@ void daemonizeUnderUnix(void) {
 /* **************************************** */
 
 void detachFromTerminalUnderUnix(int doChdir) {
-
 #ifndef WIN32
 #ifdef MAKE_WITH_SYSLOG
   /* Child processes must log to syslog.
@@ -191,7 +220,13 @@ void detachFromTerminalUnderUnix(int doChdir) {
     myGlobals.runningPref.useSyslog = DEFAULT_SYSLOG_FACILITY;
 #endif /* MAKE_WITH_SYSLOG */
 
-  if(doChdir) (void)chdir("/");
+  if(doChdir) {
+    int ret = chdir("/");
+
+    if(ret != 0)
+      traceEvent(CONST_TRACE_WARNING, "Chdir(/) failed");
+  }
+
   setsid();  /* detach from the terminal */
 
   fclose(stdin);
@@ -491,38 +526,52 @@ void handleProtocols(void) {
   }
 
   while(proto != NULL) {
-    char* protoName = strchr(proto, '=');
+    char* protoName;
+    int len, i, ignore_protocol;
 
-    if(protoName == NULL)
-      traceEvent(CONST_TRACE_INFO,
-		 "PROTO_INIT: Unknown protocol '%s'. It has been ignored",
-		 proto);
-    else {
-      char tmpStr[255];
-      int len;
+    ignore_protocol = 0;
 
-      protoName[0] = '\0';
-      memset(tmpStr, 0, sizeof(tmpStr));
-      strncpy(tmpStr, &protoName[1], sizeof(tmpStr));
-      len = strlen(tmpStr);
-
-      if(tmpStr[len-1] != '|') {
-	/* Make sure that the string ends with '|' */
-	tmpStr[len] = '|';
-	tmpStr[len+1] = '\0';
+    len = strlen(proto);
+    for(i=0; i<len; i++) {
+      if(iscntrl(proto[i]) || (!isascii(proto[i]))) {
+	ignore_protocol = 1;
       }
+    }
+
+    if(!ignore_protocol) {
+      protoName = strchr(proto, '=');
+
+      if(protoName == NULL)
+	traceEvent(CONST_TRACE_INFO,
+		   "PROTO_INIT: Unknown protocol '%s'. It has been ignored",
+		   proto);
+      else {
+	char tmpStr[255];
+
+	protoName[0] = '\0';
+	memset(tmpStr, 0, sizeof(tmpStr));
+	strncpy(tmpStr, &protoName[1], sizeof(tmpStr));
+	len = strlen(tmpStr);
+
+	if(tmpStr[len-1] != '|') {
+	  /* Make sure that the string ends with '|' */
+	  tmpStr[len] = '|';
+	  tmpStr[len+1] = '\0';
+	}
 
 #ifdef DEBUG
-      traceEvent(CONST_TRACE_INFO, "          %30s %s", proto, tmpStr);
+	traceEvent(CONST_TRACE_INFO, "          %30s %s", proto, tmpStr);
 #endif
 
-      handleProtocolList(proto, tmpStr);
+	handleProtocolList(proto, tmpStr);
 
+      }
     }
+
     proto = strtok_r(NULL, ",", &strtokState);
   }
 
-  if(buffer !=NULL)
+  if(buffer != NULL)
     free(buffer);
 }
 
@@ -612,9 +661,7 @@ static void purgeIpPorts(int theDevice) {
 
 /* **************************************** */
 
-
 void* scanIdleLoop(void* notUsed _UNUSED_) {
-
   traceEvent(CONST_TRACE_INFO, "THREADMGMT[t%lu]: SIH: Idle host scan thread starting [p%d]",
              pthread_self(), getpid());
 
@@ -629,13 +676,13 @@ void* scanIdleLoop(void* notUsed _UNUSED_) {
     ntopSleepWhileSameState(60 /* do not change */);
     if(myGlobals.ntopRunState > FLAG_NTOPSTATE_RUN) break;
 
-    if(myGlobals.runningPref.rFileName == NULL)
+    if(myGlobals.pcap_file_list == NULL)
       myGlobals.actTime = time(NULL);
 
     for(i=0; i<myGlobals.numDevices; i++)
       if(!myGlobals.device[i].virtualDevice) {
-        if((!myGlobals.runningPref.stickyHosts) 
-	   && (!myGlobals.runningPref.rFileName))
+        if((!myGlobals.runningPref.stickyHosts)
+	   && (!myGlobals.pcap_file_list))
 	  purged += purgeIdleHosts(i);
 #if !defined(__FreeBSD__)
 	purgeIpPorts(i);
@@ -680,7 +727,7 @@ void* scanFingerprintLoop(void* notUsed _UNUSED_) {
     ntopSleepWhileSameState(CONST_FINGERPRINT_LOOP_INTERVAL);
     if(myGlobals.ntopRunState > FLAG_NTOPSTATE_RUN) break;
 
-    if(myGlobals.runningPref.rFileName == NULL)
+    if(myGlobals.pcap_file_list == NULL)
       myGlobals.actTime = time(NULL);
     countCycle++;
 #ifdef FINGERPRINT_DEBUG
@@ -770,7 +817,7 @@ static void cleanupThreadIs(char *buf, int sizeofbuf) {
     for(i=0; i<myGlobals.numDevices; i++) {
       if((myGlobals.device[i].netflowGlobals != NULL) &&
          (pthread_self() == myGlobals.device[i].netflowGlobals->netFlowThread)) {
-        safe_snprintf(__FILE__, __LINE__, buf, sizeofbuf, "NF(%s)", 
+        safe_snprintf(__FILE__, __LINE__, buf, sizeofbuf, "NF(%s)",
 		      myGlobals.device[i].humanFriendlyName);
         break;
       }
@@ -781,7 +828,7 @@ static void cleanupThreadIs(char *buf, int sizeofbuf) {
     for(i=0; i<myGlobals.numDevices; i++) {
       if((myGlobals.device[i].sflowGlobals != NULL) &&
          (pthread_self() == myGlobals.device[i].sflowGlobals->sflowThread)) {
-        safe_snprintf(__FILE__, __LINE__, buf, sizeofbuf, "SF(%s)", 
+        safe_snprintf(__FILE__, __LINE__, buf, sizeofbuf, "SF(%s)",
 		      myGlobals.device[i].humanFriendlyName);
         break;
       }
@@ -818,8 +865,7 @@ void runningThreads(char *buf, int sizeofbuf, int do_join) {
   }
 
   for(i=0; i<myGlobals.numDequeueAddressThreads; i++) {
-    if((myGlobals.dequeueAddressThreadId[i] != 0)
-       && (myGlobals.dequeueAddressThreadId[i] != (pthread_t)-1)) {
+    if(myGlobals.dequeueAddressThreadId[i] != 0) {
       if(!do_join) {
 	safe_snprintf(__FILE__, __LINE__, buf2, sizeof(buf2), " DNSAR%d", i+1);
 	safe_strncat(buf, sizeofbuf, buf2);
@@ -833,6 +879,11 @@ void runningThreads(char *buf, int sizeofbuf, int do_join) {
     }
   }
 
+  if(myGlobals.allDevs != NULL) {
+    pcap_freealldevs(myGlobals.allDevs);
+    myGlobals.allDevs = NULL;
+  }
+
   if(myGlobals.device != NULL) {
     for(i=0; i<myGlobals.numDevices; i++) {
       if((myGlobals.device[i].pcapDispatchThreadId != 0) &&
@@ -907,11 +958,11 @@ void runningThreads(char *buf, int sizeofbuf, int do_join) {
 	  safe_strncat(buf, sizeofbuf, buf2);
 	} else {
 	  traceEvent(CONST_TRACE_INFO, "Signaling thread NPA(%s)",
-		     myGlobals.device[i].humanFriendlyName);	 
+		     myGlobals.device[i].humanFriendlyName);
 	  signalCondvar(&myGlobals.device[i].queueCondvar);
 	  /*
 	  traceEvent(CONST_TRACE_INFO, "Joining thread NPA(%s)",
-		     myGlobals.device[i].humanFriendlyName);	  
+		     myGlobals.device[i].humanFriendlyName);
 	  if(joinThread(&myGlobals.device[i].dequeuePacketThreadId) != 0)
 	    traceEvent(CONST_TRACE_INFO, "joinThread() returned %s", strerror(errno));
 	  else
@@ -927,19 +978,20 @@ void runningThreads(char *buf, int sizeofbuf, int do_join) {
 
 /* Report statistics and write out the raw packet file */
 RETSIGTYPE cleanup(int signo) {
-  int i, j;
+  int i, j, idx;
   char buf[128];
   static int cleanup_called = 0;
 
-  if(myGlobals.ntopRunState <= FLAG_NTOPSTATE_SHUTDOWN) {
-    static u_char caught_signal = 0;
-    traceEvent(CONST_TRACE_INFO, "CLEANUP[t%lu]: ntop caught signal %d", pthread_self(), signo);
+  if(myGlobals.ntopRunState < FLAG_NTOPSTATE_RUN) {
+    cleanup_called = 1; /* Terminate immediately */
+  }
 
-    if(caught_signal){
-      traceEvent(CONST_TRACE_INFO, "ntop is now quitting...");
-      exit(0);
-    } else
-      caught_signal = 1;
+  traceEvent(CONST_TRACE_INFO, "CLEANUP[t%lu]: ntop caught signal %d [state=%d]", 
+	     pthread_self(), signo, myGlobals.ntopRunState);
+
+  if(cleanup_called) {
+    traceEvent(CONST_TRACE_INFO, "ntop is now quitting...");
+    exit(0);
   }
 
 #ifndef WIN32
@@ -988,6 +1040,7 @@ RETSIGTYPE cleanup(int signo) {
   setRunState(FLAG_NTOPSTATE_SHUTDOWN);
 
   if(cleanup_called) {
+    traceEvent(CONST_TRACE_INFO, "CLEANUP[t%lu]: exiting", pthread_self());
     exit(0);
   }
 
@@ -1121,17 +1174,13 @@ RETSIGTYPE cleanup(int signo) {
 	  free(myGlobals.device[i].ipPorts[port]);
     }
 
-    if(myGlobals.device[i].ipPorts)    
+    if(myGlobals.device[i].ipPorts)
       free(myGlobals.device[i].ipPorts);
 
-    if(myGlobals.device[i].packetQueue) 
+    if(myGlobals.device[i].packetQueue)
       free(myGlobals.device[i].packetQueue);
 
-    accessMutex(&myGlobals.tcpSessionsMutex, "cleanup");
-    if(myGlobals.device[i].tcpSession != NULL)
-      free(myGlobals.device[i].tcpSession);
-    releaseMutex(&myGlobals.tcpSessionsMutex);
-
+    free(myGlobals.device[i].tcpSession);
     free(myGlobals.device[i].humanFriendlyName);
     free(myGlobals.device[i].uniqueIfName);
     free(myGlobals.device[i].name);
@@ -1154,8 +1203,8 @@ RETSIGTYPE cleanup(int signo) {
         free(tmp);
       }
     }
-#endif  
-    
+#endif
+
     while(myGlobals.device[i].asStats) {
       AsStats *next = myGlobals.device[i].asStats->next;
       free(myGlobals.device[i].asStats);
@@ -1176,8 +1225,11 @@ RETSIGTYPE cleanup(int signo) {
 
   if(myGlobals.startedAs != NULL) free(myGlobals.startedAs);
 
-  tryLockMutex(&myGlobals.tcpSessionsMutex, "cleanup");
-  deleteMutex(&myGlobals.tcpSessionsMutex);
+    for(idx=0; idx<NUM_SESSION_MUTEXES; idx++) {
+      tryLockMutex(&myGlobals.tcpSessionsMutex[idx], "cleanup");
+      deleteMutex(&myGlobals.tcpSessionsMutex[idx]);
+    }
+
   tryLockMutex(&myGlobals.purgePortsMutex, "cleanup");
   deleteMutex(&myGlobals.purgePortsMutex);
   tryLockMutex(&myGlobals.securityItemsMutex, "cleanup");
@@ -1214,7 +1266,6 @@ RETSIGTYPE cleanup(int signo) {
   if(myGlobals.runningPref.devices != NULL) free(myGlobals.runningPref.devices);
 
   /* One day we should free myGlobals.countryFlagHead */
-
   free(myGlobals.runningPref.pcapLogBasePath);
   /* free(myGlobals.dbPath); -- later, need this to remove pid */
   if(myGlobals.spoolPath) free(myGlobals.spoolPath);
