@@ -1375,6 +1375,7 @@ void* invokeNtop(LPTSTR szAppParameters) {
     }
 
   ntop_main(dwNewArgc, lpszNewArgv);
+  SetEvent(hServerStopEvent); // Signal main thread that we're leaving
   return(NULL);
 }
 
@@ -2390,3 +2391,141 @@ strptime(const char *buf, const char *fmt, struct tm *tm)
 	return ret;
 }
 
+/* ********************************* */
+
+static const char *
+inet_ntop4(src, dst, size)
+     const u_char *src;
+     char *dst;
+     size_t size;
+{
+  static const char fmt[] = "%u.%u.%u.%u";
+  char tmp[sizeof "255.255.255.255"];
+  int nprinted;
+
+  nprinted = safe_snprintf(__FILE__, __LINE__, tmp, sizeof(tmp), fmt, src[0], src[1], src[2], src[3]);
+  if (nprinted < 0)
+    return (NULL);  /* we assume "errno" was set by "snprintf()" */
+  if ((size_t)nprinted > size) {
+    errno = ENOSPC;
+    return (NULL);
+  }
+  strcpy(dst, tmp);
+  return (dst);
+}
+
+#define NS_IN6ADDRSZ 16
+
+static const char *inet_ntop6(const u_char *src, char *dst, size_t size) {
+  /*
+   * Note that int32_t and int16_t need only be "at least" large enough
+   * to contain a value of the specified size.  On some systems, like
+   * Crays, there is no such thing as an integer variable with 16 bits.
+   * Keep this in mind if you think this function should have been coded
+   * to use pointer overlays.  All the world's not a VAX.
+   */
+  char tmp[64], *tp;
+  struct { int base, len; } best, cur;
+  u_int words[NS_IN6ADDRSZ / NS_INT16SZ];
+  int i;
+
+  memset(tmp, 0, sizeof(tmp));
+
+  /*
+   * Preprocess:
+   *      Copy the input (bytewise) array into a wordwise array.
+   *      Find the longest run of 0x00's in src[] for :: shorthanding.
+   */
+  memset(words, '\0', sizeof words);
+  for (i = 0; i < NS_IN6ADDRSZ; i++)
+    words[i / 2] |= (src[i] << ((1 - (i % 2)) << 3));
+  best.base = -1;
+  cur.base = -1;
+  for (i = 0; i < (NS_IN6ADDRSZ / NS_INT16SZ); i++) {
+    if (words[i] == 0) {
+      if (cur.base == -1)
+	cur.base = i, cur.len = 1;
+      else
+	cur.len++;
+    } else {
+      if (cur.base != -1) {
+	if (best.base == -1 || cur.len > best.len)
+	  best = cur;
+	cur.base = -1;
+      }
+    }
+  }
+  if (cur.base != -1) {
+
+    if (best.base == -1 || cur.len > best.len)
+      best = cur;
+  }
+  if (best.base != -1 && best.len < 2)
+    best.base = -1;
+
+  /*
+   * Format the result.
+   */
+  tp = tmp;
+
+  for (i = 0; i < (NS_IN6ADDRSZ / NS_INT16SZ); i++) {
+    /* Are we inside the best run of 0x00's? */
+    if (best.base != -1 && i >= best.base &&
+	i < (best.base + best.len)) {
+      if (i == best.base)
+	*tp++ = ':';
+      continue;
+    }
+    /* Are we following an initial run of 0x00s or any real hex? */
+    if (i != 0)
+      *tp++ = ':';
+    /* Is this address an encapsulated IPv4? */
+    if (i == 6 && best.base == 0 &&
+	(best.len == 6 || (best.len == 5 && words[5] == 0xffff))) {
+      if (!inet_ntop4(src+12, tp, sizeof tmp - (tp - tmp)))
+	return (NULL);
+      tp += strlen(tp);
+      break;
+    }
+    tp += safe_snprintf(__FILE__, __LINE__, tp, sizeof(tmp), "%x", words[i]);
+  }
+
+  /* Was it a trailing run of 0x00's? */
+  if (best.base != -1 && (best.base + best.len) ==
+      (NS_IN6ADDRSZ / NS_INT16SZ))
+    *tp++ = ':';
+  *tp++ = '\0';
+
+  /*
+   * Check for overflow, copy, and we're done.
+   */
+  if ((size_t)(tp - tmp) > size) {
+    errno = ENOSPC;
+    return (NULL);
+  }
+  strcpy(dst, tmp);
+  return (dst);
+}
+
+PCSTR
+WSAAPI
+inet_ntop(
+    __in                                INT             af,
+    __in                                PVOID           src,
+    __out_ecount(StringBufSize)         PSTR            dst,
+    __in                                size_t          size
+    ){
+  switch (af) {
+  case AF_INET:
+    return (inet_ntop4(src, dst, size));
+  case AF_INET6:
+    return (inet_ntop6(src, dst, size));
+  default:
+    errno = -1;
+    return (NULL);
+  }
+  /* NOTREACHED */
+}
+
+
+
