@@ -22,8 +22,9 @@
 
 #ifdef MAKE_STATIC_PLUGIN
 extern PluginInfo* icmpPluginEntryFctn(void);
-extern PluginInfo* sflowPluginEntryFctn(void);
+extern PluginInfo* sflowPluginEntryFctn(void)
 extern PluginInfo* rrdPluginEntryFctn(void);
+extern PluginInfo* cpacketPluginEntryFctn(void);
 extern PluginInfo* netflowPluginEntryFctn(void);
 #endif
 
@@ -85,6 +86,8 @@ static void loadPlugin(char* dirName, char* pluginName) {
     pluginInfo = netflowPluginEntryFctn();
   else if(strcmp(pluginName, "rrdPlugin") == 0)
     pluginInfo = rrdPluginEntryFctn();
+  else if(strcmp(pluginName, "cpacketPlugin") == 0)
+    pluginInfo = cpacketPluginEntryFctn();
   else
     pluginInfo = NULL;
 
@@ -240,6 +243,7 @@ void loadPlugins(void) {
   loadPlugin(NULL, "sflowPlugin");
   loadPlugin(NULL, "netflowPlugin");
   loadPlugin(NULL, "rrdPlugin");
+  loadPlugin(NULL, "cpacketPlugin");
 #endif /* MAKE_STATIC_PLUGIN */
 }
 
