@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2002-04 Luca Deri <deri@ntop.org>
+ *  Copyright (C) 2002-07 Luca Deri <deri@ntop.org>
  *
  *  		       http://www.ntop.org/
  *
@@ -23,6 +23,7 @@
 
 #include <rrd.h>
 
+#define MAX_NETWORK_EXPANSION   24 /* /24 */
 /*
  * Extra pages
  */
@@ -35,7 +36,7 @@
 #define FLAG_RRD_DETAIL_LOW                 0
 #define FLAG_RRD_DETAIL_MEDIUM              1
 #define FLAG_RRD_DETAIL_HIGH                2
-#define CONST_RRD_DETAIL_DEFAULT            FLAG_RRD_DETAIL_HIGH
+#define CONST_RRD_DETAIL_DEFAULT            FLAG_RRD_DETAIL_MEDIUM
 
 #define FLAG_RRD_ACTION_NONE                0
 #define FLAG_RRD_ACTION_GRAPH               1
@@ -71,7 +72,7 @@
 #define DEFAULT_RRD_DAYS                    90   /* days of hour by hour data (default) */
 #define DEFAULT_RRD_MONTHS                  36   /* months of day by day data (default) */
 #define DEFAULT_RRD_DUMP_DELAY              10   /* ms (default) */
-
+#define DEFAULT_RRD_HEARTBEAT_MULTIPLIER     3   /* multiplier */
 #define AS_RRD_DUMP_PKTS_THRESHOLD          10   /* packets */
 
 /* ****************************************************** */
@@ -248,26 +249,30 @@ static const char *rrd_summary_packets[] = {
   NULL
 };
 
-static const char *rrd_summary_new_flows[] = { 
-  "NF_numFlows",
-  "NF_numDiscardedFlows",
-  NULL
+struct nameLabel {
+  char *name, *label;
 };
 
-static const char *rrd_summary_new_nf_flows[] = { 
-  "NF_newTcpNetFlows",
-  "NF_newUdpNetFlows",
-  "NF_newIcmpNetFlows",
-  "NF_newOtherNetFlows",
-  NULL
+static const struct nameLabel rrd_summary_new_flows[] = { 
+  { "NF_numFlows", "Total Flows" },
+  { "NF_numDiscardedFlows", "Discarded Flows" },
+  { NULL, NULL }
 };
 
-static const char *rrd_summary_new_nf_flows_size[] = { 
-  "NF_avgTcpNewFlowSize",
-  "NF_avgUdpNewFlowSize",
-  "NF_avgICMPNewFlowSize",
-  "NF_avgOtherNewFlowSize",
-  NULL
+static const struct nameLabel rrd_summary_new_nf_flows[] = { 
+  { "NF_newTcpNetFlows", "TCP" },
+  { "NF_newUdpNetFlows", "UDP" },
+  { "NF_newIcmpNetFlows", "ICMP" },
+  { "NF_newOtherNetFlows", "Other" },
+  { NULL, NULL }
+};
+
+static const struct nameLabel rrd_summary_new_nf_flows_size[] = { 
+  { "NF_avgTcpNewFlowSize", "TCP" },
+  { "NF_avgUdpNewFlowSize", "UDP" },
+  { "NF_avgICMPNewFlowSize", "ICMP" },
+  { "NF_avgOtherNewFlowSize", "Other" },
+  { NULL, NULL }
 };
 
 static const char *rrd_summary_proto_bytes[] = { 
@@ -336,6 +341,19 @@ static const char *rrd_summary_nf_if_pkts[] = {
  NULL
 };
 
+static const struct nameLabel rrd_filters[] = { 
+  { "upTo", "Packet Size" },
+  { "cast", "Broad/Multi-cast" },
+  { "Flow", "Flows" },
+  { "Efficiency", "Network Efficiency" },
+  { "NF_", "NetFlow" },
+  /* Generic matches go at the end */
+  { "Sent", "Sent" },
+  { "Rcvd", "Received" },
+  { "Bytes", "Volume" },
+  { "Pkts", "Packets" },
+  { NULL, NULL }
+};
 
 #ifdef MAX_RRD_PROCESS_BUFFER
 static float rrdprocessBuffer[MAX_RRD_PROCESS_BUFFER];
